-- ********************************************************************************
-- *  Copyright (C) Thorsten Gaertner, Oststeinbek / Germany 2004                 *
-- ********************************************************************************
--
-- ********************************************************************************
-- *  This source file is provided "as is" and WITHOUT any express or implied     *
-- *  warranties, that this source file is                                        *
-- *  1. free from any claims of infringement,                                    *
-- *  2. the merchantability or fitness for a particular purpose.                 *
-- ********************************************************************************
--
-- ********************************************************************************
-- *  File        : DEMULTIPLEXER_E3_TO_E1.vhd                                    *
-- *  Version     : 1.0                                                           *
-- *  Target      : Plain VHDL                                                    *
-- *  Description : E3 (G.751) Demultiplexer for 16 E1 transparent (G.704)        *
-- *                channels with E2 (G.742) intermediate layer                   *
-- ********************************************************************************

library IEEE;
use     IEEE.STD_LOGIC_1164.ALL;
use     IEEE.STD_LOGIC_ARITH.ALL;
use     IEEE.STD_LOGIC_UNSIGNED.ALL;

-- ********************************************************************************

entity DEMULTIPLEXER_E3_TO_E1 is
  port (
    RESET           : in  std_logic;                      -- Reset
    E3_RX_CLK       : in  std_logic;                      -- RX input data clock
    E3_RX_DATA      : in  std_logic;                      -- RX input data signal
    E3_RX_LCV       : in  std_logic;                      -- RX code violation
    E3_RX_LOS       : in  std_logic;                      -- RX loss of signal
    E3_RX_LOL       : in  std_logic;                      -- RX loss of lock
    E3_REF_CLK      : out std_logic;                      -- RX reference clock output
    E3_FRAME_START  : out std_logic;                      -- Frame Pulse
    E3_SYNC         : out std_logic;                      -- State : Frame Synchron
    E3_RAI          : out std_logic;                      -- State : RAI bit
    E3_NA           : out std_logic;                      -- State : NA bit
    E3_AIS          : out std_logic;                      -- State : Alarm Ind. Signal
    E3_LOS          : out std_logic;                      -- State : Loss Of Signal
    E3_REMOTE_EN    : in  std_logic;                      -- Remote Channel : Enable
    E3_REMOTE_DATA  : out std_logic_vector (3 downto 0);  -- Remote Channel : RX Data
    E2_CH1_SYNC     : out std_logic;                      -- E2 Channel 1 : Frame Synchronous
    E2_CH1_RAI      : out std_logic;                      -- E2 Channel 1 : RAI Bit
    E2_CH1_NA       : out std_logic;                      -- E2 Channel 1 : NA Bit
    E2_CH1_AIS      : out std_logic;                      -- E2 Channel 1 : Alarm Ind. Signal
    E2_CH1_LOS      : out std_logic;                      -- E2 Channel 1 : Loss Of Signal
    E2_CH2_SYNC     : out std_logic;                      -- E2 Channel 2 : Frame Synchronous
    E2_CH2_RAI      : out std_logic;                      -- E2 Channel 2 : RAI Bit
    E2_CH2_NA       : out std_logic;                      -- E2 Channel 2 : NA Bit
    E2_CH2_AIS      : out std_logic;                      -- E2 Channel 2 : Alarm Ind. Signal
    E2_CH2_LOS      : out std_logic;                      -- E2 Channel 2 : Loss Of Signal
    E2_CH3_SYNC     : out std_logic;                      -- E2 Channel 3 : Frame Synchronous
    E2_CH3_RAI      : out std_logic;                      -- E2 Channel 3 : RAI Bit
    E2_CH3_NA       : out std_logic;                      -- E2 Channel 3 : NA Bit
    E2_CH3_AIS      : out std_logic;                      -- E2 Channel 3 : Alarm Ind. Signal
    E2_CH3_LOS      : out std_logic;                      -- E2 Channel 3 : Loss Of Signal
    E2_CH4_SYNC     : out std_logic;                      -- E2 Channel 4 : Frame Synchronous
    E2_CH4_RAI      : out std_logic;                      -- E2 Channel 4 : RAI Bit
    E2_CH4_NA       : out std_logic;                      -- E2 Channel 4 : NA Bit
    E2_CH4_AIS      : out std_logic;                      -- E2 Channel 4 : Alarm Ind. Signal
    E2_CH4_LOS      : out std_logic;                      -- E2 Channel 4 : Loss Of Signal
    E1_CH11_RX_VAL  : out std_logic;                      -- E1 Channel 11 Data Valid
    E1_CH11_RX_DATA : out std_logic;                      -- E1 Channel 11 Data
    E1_CH12_RX_VAL  : out std_logic;                      -- E1 Channel 12 Data Valid
    E1_CH12_RX_DATA : out std_logic;                      -- E1 Channel 12 Data
    E1_CH13_RX_VAL  : out std_logic;                      -- E1 Channel 13 Data Valid
    E1_CH13_RX_DATA : out std_logic;                      -- E1 Channel 13 Data
    E1_CH14_RX_VAL  : out std_logic;                      -- E1 Channel 14 Data Valid
    E1_CH14_RX_DATA : out std_logic;                      -- E1 Channel 14 Data
    E1_CH21_RX_VAL  : out std_logic;                      -- E1 Channel 21 Data Valid
    E1_CH21_RX_DATA : out std_logic;                      -- E1 Channel 21 Data
    E1_CH22_RX_VAL  : out std_logic;                      -- E1 Channel 22 Data Valid
    E1_CH22_RX_DATA : out std_logic;                      -- E1 Channel 22 Data
    E1_CH23_RX_VAL  : out std_logic;                      -- E1 Channel 23 Data Valid
    E1_CH23_RX_DATA : out std_logic;                      -- E1 Channel 23 Data
    E1_CH24_RX_VAL  : out std_logic;                      -- E1 Channel 24 Data Valid
    E1_CH24_RX_DATA : out std_logic;                      -- E1 Channel 24 Data
    E1_CH31_RX_VAL  : out std_logic;                      -- E1 Channel 31 Data Valid
    E1_CH31_RX_DATA : out std_logic;                      -- E1 Channel 31 Data
    E1_CH32_RX_VAL  : out std_logic;                      -- E1 Channel 32 Data Valid
    E1_CH32_RX_DATA : out std_logic;                      -- E1 Channel 32 Data
    E1_CH33_RX_VAL  : out std_logic;                      -- E1 Channel 33 Data Valid
    E1_CH33_RX_DATA : out std_logic;                      -- E1 Channel 33 Data
    E1_CH34_RX_VAL  : out std_logic;                      -- E1 Channel 34 Data Valid
    E1_CH34_RX_DATA : out std_logic;                      -- E1 Channel 34 Data
    E1_CH41_RX_VAL  : out std_logic;                      -- E1 Channel 41 Data Valid
    E1_CH41_RX_DATA : out std_logic;                      -- E1 Channel 41 Data
    E1_CH42_RX_VAL  : out std_logic;                      -- E1 Channel 42 Data Valid
    E1_CH42_RX_DATA : out std_logic;                      -- E1 Channel 42 Data
    E1_CH43_RX_VAL  : out std_logic;                      -- E1 Channel 43 Data Valid
    E1_CH43_RX_DATA : out std_logic;                      -- E1 Channel 43 Data
    E1_CH44_RX_VAL  : out std_logic;                      -- E1 Channel 44 Data Valid
    E1_CH44_RX_DATA : out std_logic                       -- E1 Channel 44 Data
  );
end DEMULTIPLEXER_E3_TO_E1;

-- ********************************************************************************

architecture DEMULTIPLEXER_E3_TO_E1 of DEMULTIPLEXER_E3_TO_E1 is

-- ********************************************************************************

component E3_G751_DEFRAMER
  port (
    RESET          : in  std_logic;                      -- Reset
    E3_RX_CLK      : in  std_logic;                      -- RX input data clock
    E3_RX_DATA     : in  std_logic;                      -- RX input data signal
    E3_RX_LCV      : in  std_logic;                      -- RX code violation
    E3_RX_LOS      : in  std_logic;                      -- RX loss of signal
    E3_RX_LOL      : in  std_logic;                      -- RX loss of lock
    E3_REF_CLK     : out std_logic;                      -- RX reference clock output
    E3_FRAME_START : out std_logic;                      -- Frame Pulse
    E3_SYNC        : out std_logic;                      -- State : Frame Synchron
    E3_RAI         : out std_logic;                      -- State : RAI bit
    E3_NA          : out std_logic;                      -- State : NA bit
    E3_AIS         : out std_logic;                      -- State : Alarm Ind. Signal
    E3_LOS         : out std_logic;                      -- State : Loss Of Signal
    E2_CH1_RX_VAL  : out std_logic;                      -- E2 Channel 1 Data Valid
    E2_CH1_RX_DATA : out std_logic;                      -- E2 Channel 1 Data
    E2_CH2_RX_VAL  : out std_logic;                      -- E2 Channel 2 Data Valid
    E2_CH2_RX_DATA : out std_logic;                      -- E2 Channel 2 Data
    E2_CH3_RX_VAL  : out std_logic;                      -- E2 Channel 3 Data Valid
    E2_CH3_RX_DATA : out std_logic;                      -- E2 Channel 3 Data
    E2_CH4_RX_VAL  : out std_logic;                      -- E2 Channel 4 Data Valid
    E2_CH4_RX_DATA : out std_logic;                      -- E2 Channel 4 Data
    E3_REMOTE_EN   : in  std_logic;                      -- Remote Channel : Enable
    E3_REMOTE_DATA : out std_logic_vector (3 downto 0)   -- Remote Channel : RX Data
  );
end component;

-- ********************************************************************************

component E2_G742_DEFRAMER
  port (
    RESET          : in  std_logic;                      -- Reset
    E2_RX_CLK      : in  std_logic;                      -- RX Input Data Clock
    E2_RX_CLK_EN   : in  std_logic;                      -- RX Input Data Clock Enable
    E2_RX_DATA     : in  std_logic;                      -- RX Input Data
    E2_RX_LCV      : in  std_logic;                      -- RX Code Violation
    E2_RX_LOS      : in  std_logic;                      -- RX Loss Of Signal
    E2_RX_LOL      : in  std_logic;                      -- RX Loss Of Lock
    E2_REF_CLK     : out std_logic;                      -- Output Ref. Clock
    E2_REF_CLK_EN  : out std_logic;                      -- Output Ref. Clock Enable
    E2_FRAME_START : out std_logic;                      -- Frame Pulse
    E2_SYNC        : out std_logic;                      -- State : Frame Synchronous
    E2_RAI         : out std_logic;                      -- State : RAI Bit
    E2_NA          : out std_logic;                      -- State : NA Bit
    E2_AIS         : out std_logic;                      -- State : Alarm Ind. Signal
    E2_LOS         : out std_logic;                      -- State : Loss Of Signal
    E1_CH1_RX_VAL  : out std_logic;                      -- E1 Channel 1 Data Valid
    E1_CH1_RX_DATA : out std_logic;                      -- E1 Channel 1 Data
    E1_CH2_RX_VAL  : out std_logic;                      -- E1 Channel 2 Data Valid
    E1_CH2_RX_DATA : out std_logic;                      -- E1 Channel 2 Data
    E1_CH3_RX_VAL  : out std_logic;                      -- E1 Channel 3 Data Valid
    E1_CH3_RX_DATA : out std_logic;                      -- E1 Channel 3 Data
    E1_CH4_RX_VAL  : out std_logic;                      -- E1 Channel 4 Data Valid
    E1_CH4_RX_DATA : out std_logic;                      -- E1 Channel 4 Data
    E2_REMOTE_EN   : in  std_logic;                      -- Remote Channel : Enable
    E2_REMOTE_DATA : out std_logic_vector (3 downto 0)   -- Remote Channel : RX Data
  );
end component;

-- ********************************************************************************

signal e3_ref_clk_i, e3_frame_start_i, e3_sync_i, e3_ais_i, e3_los_i, gnd : std_logic;
signal e2_ch1_rx_val , e2_ch2_rx_val , e2_ch3_rx_val , e2_ch4_rx_val      : std_logic;
signal e2_ch1_rx_data, e2_ch2_rx_data, e2_ch3_rx_data, e2_ch4_rx_data     : std_logic;

-- ********************************************************************************

begin

-- ********************************************************************************

gnd <= '0';

-- ********************************************************************************
-- * E3-Deframer (RX) according to ITU-T G.751 (34368 kbit/sec) : LINE - DEFRAMER *
-- ********************************************************************************

E3_DEFRAMER : E3_G751_DEFRAMER
  port map (
    RESET          => RESET,             -- in  std_logic;                      -- Reset
    E3_RX_CLK      => E3_RX_CLK,         -- in  std_logic;                      -- RX input data clock
    E3_RX_DATA     => E3_RX_DATA,        -- in  std_logic;                      -- RX input data signal
    E3_RX_LCV      => E3_RX_LCV,         -- in  std_logic;                      -- RX code violation
    E3_RX_LOS      => E3_RX_LOS,         -- in  std_logic;                      -- RX loss of signal
    E3_RX_LOL      => E3_RX_LOL,         -- in  std_logic;                      -- RX loss of lock
    E3_REF_CLK     => e3_ref_clk_i,      -- out std_logic;                      -- RX reference clock output
    E3_FRAME_START => e3_frame_start_i,  -- out std_logic;                      -- Frame Pulse
    E3_SYNC        => e3_sync_i,         -- out std_logic;                      -- State : Frame Synchron
    E3_RAI         => E3_RAI,            -- out std_logic;                      -- State : RAI bit
    E3_NA          => E3_NA,             -- out std_logic;                      -- State : NA bit
    E3_AIS         => e3_ais_i,          -- out std_logic;                      -- State : Alarm Ind. Signal
    E3_LOS         => e3_los_i,          -- out std_logic;                      -- State : Loss Of Signal
    E2_CH1_RX_VAL  => e2_ch1_rx_val,     -- out std_logic;                      -- E2 Channel 1 Data Valid
    E2_CH1_RX_DATA => e2_ch1_rx_data,    -- out std_logic;                      -- E2 Channel 1 Data
    E2_CH2_RX_VAL  => e2_ch2_rx_val,     -- out std_logic;                      -- E2 Channel 2 Data Valid
    E2_CH2_RX_DATA => e2_ch2_rx_data,    -- out std_logic;                      -- E2 Channel 2 Data
    E2_CH3_RX_VAL  => e2_ch3_rx_val,     -- out std_logic;                      -- E2 Channel 3 Data Valid
    E2_CH3_RX_DATA => e2_ch3_rx_data,    -- out std_logic;                      -- E2 Channel 3 Data
    E2_CH4_RX_VAL  => e2_ch4_rx_val,     -- out std_logic;                      -- E2 Channel 4 Data Valid
    E2_CH4_RX_DATA => e2_ch4_rx_data,    -- out std_logic;                      -- E2 Channel 4 Data
    E3_REMOTE_EN   => E3_REMOTE_EN,      -- in  std_logic;                      -- Remote Channel : Enable
    E3_REMOTE_DATA => E3_REMOTE_DATA     -- out std_logic_vector (3 downto 0)   -- Remote Channel : RX Data
  );

E3_REF_CLK     <= e3_ref_clk_i;
E3_FRAME_START <= e3_frame_start_i;
E3_SYNC        <= e3_sync_i;
E3_AIS         <= e3_ais_i;
E3_LOS         <= e3_los_i;

-- ********************************************************************************
-- * E2-Deframer (RX) according to ITU-T G.742 (8448 kbit/sec) :  DEFRAMER No. 1  *
-- ********************************************************************************

E2_DEFRAMER_1 : E2_G742_DEFRAMER
  port map (
    RESET          => RESET,             -- in  std_logic;                      -- Reset
    E2_RX_CLK      => e3_ref_clk_i,      -- in  std_logic;                      -- RX Input Data Clock
    E2_RX_CLK_EN   => e2_ch1_rx_val,     -- in  std_logic;                      -- RX Input Data Clock Enable
    E2_RX_DATA     => e2_ch1_rx_data,    -- in  std_logic;                      -- RX Input Data
    E2_RX_LCV      => gnd,               -- in  std_logic;                      -- RX Code Violation
    E2_RX_LOS      => E3_RX_LOS,         -- in  std_logic;                      -- RX Loss Of Signal
    E2_RX_LOL      => E3_RX_LOL,         -- in  std_logic;                      -- RX Loss Of Lock
    E2_REF_CLK     => open,              -- out std_logic;                      -- Output Ref. Clock
    E2_REF_CLK_EN  => open,              -- out std_logic;                      -- Output Ref. Clock Enable
    E2_FRAME_START => open,              -- out std_logic;                      -- Frame Pulse
    E2_SYNC        => E2_CH1_SYNC,       -- out std_logic;                      -- State : Frame Synchronous
    E2_RAI         => E2_CH1_RAI,        -- out std_logic;                      -- State : RAI Bit
    E2_NA          => E2_CH1_NA,         -- out std_logic;                      -- State : NA Bit
    E2_AIS         => E2_CH1_AIS,        -- out std_logic;                      -- State : Alarm Ind. Signal
    E2_LOS         => E2_CH1_LOS,        -- out std_logic;                      -- State : Loss Of Signal
    E1_CH1_RX_VAL  => E1_CH11_RX_VAL,    -- out std_logic;                      -- E1 Channel 1 Data Valid
    E1_CH1_RX_DATA => E1_CH11_RX_DATA,   -- out std_logic;                      -- E1 Channel 1 Data
    E1_CH2_RX_VAL  => E1_CH12_RX_VAL,    -- out std_logic;                      -- E1 Channel 2 Data Valid
    E1_CH2_RX_DATA => E1_CH12_RX_DATA,   -- out std_logic;                      -- E1 Channel 2 Data
    E1_CH3_RX_VAL  => E1_CH13_RX_VAL,    -- out std_logic;                      -- E1 Channel 3 Data Valid
    E1_CH3_RX_DATA => E1_CH13_RX_DATA,   -- out std_logic;                      -- E1 Channel 3 Data
    E1_CH4_RX_VAL  => E1_CH14_RX_VAL,    -- out std_logic;                      -- E1 Channel 4 Data Valid
    E1_CH4_RX_DATA => E1_CH14_RX_DATA,   -- out std_logic;                      -- E1 Channel 4 Data
    E2_REMOTE_EN   => gnd,               -- in  std_logic;                      -- Remote Channel : Enable
    E2_REMOTE_DATA => open               -- out std_logic_vector (3 downto 0)   -- Remote Channel : RX Data
  );

-- ********************************************************************************
-- * E2-Deframer (RX) according to ITU-T G.742 (8448 kbit/sec) :  DEFRAMER No. 2  *
-- ********************************************************************************

E2_DEFRAMER_2 : E2_G742_DEFRAMER
  port map (
    RESET          => RESET,             -- in  std_logic;                      -- Reset
    E2_RX_CLK      => e3_ref_clk_i,      -- in  std_logic;                      -- RX Input Data Clock
    E2_RX_CLK_EN   => e2_ch2_rx_val,     -- in  std_logic;                      -- RX Input Data Clock Enable
    E2_RX_DATA     => e2_ch2_rx_data,    -- in  std_logic;                      -- RX Input Data
    E2_RX_LCV      => gnd,               -- in  std_logic;                      -- RX Code Violation
    E2_RX_LOS      => E3_RX_LOS,         -- in  std_logic;                      -- RX Loss Of Signal
    E2_RX_LOL      => E3_RX_LOL,         -- in  std_logic;                      -- RX Loss Of Lock
    E2_REF_CLK     => open,              -- out std_logic;                      -- Output Ref. Clock
    E2_REF_CLK_EN  => open,              -- out std_logic;                      -- Output Ref. Clock Enable
    E2_FRAME_START => open,              -- out std_logic;                      -- Frame Pulse
    E2_SYNC        => E2_CH2_SYNC,       -- out std_logic;                      -- State : Frame Synchronous
    E2_RAI         => E2_CH2_RAI,        -- out std_logic;                      -- State : RAI Bit
    E2_NA          => E2_CH2_NA,         -- out std_logic;                      -- State : NA Bit
    E2_AIS         => E2_CH2_AIS,        -- out std_logic;                      -- State : Alarm Ind. Signal
    E2_LOS         => E2_CH2_LOS,        -- out std_logic;                      -- State : Loss Of Signal
    E1_CH1_RX_VAL  => E1_CH21_RX_VAL,    -- out std_logic;                      -- E1 Channel 1 Data Valid
    E1_CH1_RX_DATA => E1_CH21_RX_DATA,   -- out std_logic;                      -- E1 Channel 1 Data
    E1_CH2_RX_VAL  => E1_CH22_RX_VAL,    -- out std_logic;                      -- E1 Channel 2 Data Valid
    E1_CH2_RX_DATA => E1_CH22_RX_DATA,   -- out std_logic;                      -- E1 Channel 2 Data
    E1_CH3_RX_VAL  => E1_CH23_RX_VAL,    -- out std_logic;                      -- E1 Channel 3 Data Valid
    E1_CH3_RX_DATA => E1_CH23_RX_DATA,   -- out std_logic;                      -- E1 Channel 3 Data
    E1_CH4_RX_VAL  => E1_CH24_RX_VAL,    -- out std_logic;                      -- E1 Channel 4 Data Valid
    E1_CH4_RX_DATA => E1_CH24_RX_DATA,   -- out std_logic;                      -- E1 Channel 4 Data
    E2_REMOTE_EN   => gnd,               -- in  std_logic;                      -- Remote Channel : Enable
    E2_REMOTE_DATA => open               -- out std_logic_vector (3 downto 0)   -- Remote Channel : RX Data
  );

-- ********************************************************************************
-- * E2-Deframer (RX) according to ITU-T G.742 (8448 kbit/sec) :  DEFRAMER No. 3  *
-- ********************************************************************************

E2_DEFRAMER_3 : E2_G742_DEFRAMER
  port map (
    RESET          => RESET,             -- in  std_logic;                      -- Reset
    E2_RX_CLK      => e3_ref_clk_i,      -- in  std_logic;                      -- RX Input Data Clock
    E2_RX_CLK_EN   => e2_ch3_rx_val,     -- in  std_logic;                      -- RX Input Data Clock Enable
    E2_RX_DATA     => e2_ch3_rx_data,    -- in  std_logic;                      -- RX Input Data
    E2_RX_LCV      => gnd,               -- in  std_logic;                      -- RX Code Violation
    E2_RX_LOS      => E3_RX_LOS,         -- in  std_logic;                      -- RX Loss Of Signal
    E2_RX_LOL      => E3_RX_LOL,         -- in  std_logic;                      -- RX Loss Of Lock
    E2_REF_CLK     => open,              -- out std_logic;                      -- Output Ref. Clock
    E2_REF_CLK_EN  => open,              -- out std_logic;                      -- Output Ref. Clock Enable
    E2_FRAME_START => open,              -- out std_logic;                      -- Frame Pulse
    E2_SYNC        => E2_CH3_SYNC,       -- out std_logic;                      -- State : Frame Synchronous
    E2_RAI         => E2_CH3_RAI,        -- out std_logic;                      -- State : RAI Bit
    E2_NA          => E2_CH3_NA,         -- out std_logic;                      -- State : NA Bit
    E2_AIS         => E2_CH3_AIS,        -- out std_logic;                      -- State : Alarm Ind. Signal
    E2_LOS         => E2_CH3_LOS,        -- out std_logic;                      -- State : Loss Of Signal
    E1_CH1_RX_VAL  => E1_CH31_RX_VAL,    -- out std_logic;                      -- E1 Channel 1 Data Valid
    E1_CH1_RX_DATA => E1_CH31_RX_DATA,   -- out std_logic;                      -- E1 Channel 1 Data
    E1_CH2_RX_VAL  => E1_CH32_RX_VAL,    -- out std_logic;                      -- E1 Channel 2 Data Valid
    E1_CH2_RX_DATA => E1_CH32_RX_DATA,   -- out std_logic;                      -- E1 Channel 2 Data
    E1_CH3_RX_VAL  => E1_CH33_RX_VAL,    -- out std_logic;                      -- E1 Channel 3 Data Valid
    E1_CH3_RX_DATA => E1_CH33_RX_DATA,   -- out std_logic;                      -- E1 Channel 3 Data
    E1_CH4_RX_VAL  => E1_CH34_RX_VAL,    -- out std_logic;                      -- E1 Channel 4 Data Valid
    E1_CH4_RX_DATA => E1_CH34_RX_DATA,   -- out std_logic;                      -- E1 Channel 4 Data
    E2_REMOTE_EN   => gnd,               -- in  std_logic;                      -- Remote Channel : Enable
    E2_REMOTE_DATA => open               -- out std_logic_vector (3 downto 0)   -- Remote Channel : RX Data
  );

-- ********************************************************************************
-- * E2-Deframer (RX) according to ITU-T G.742 (8448 kbit/sec) :  DEFRAMER No. 4  *
-- ********************************************************************************

E2_DEFRAMER_4 : E2_G742_DEFRAMER
  port map (
    RESET          => RESET,             -- in  std_logic;                      -- Reset
    E2_RX_CLK      => e3_ref_clk_i,      -- in  std_logic;                      -- RX Input Data Clock
    E2_RX_CLK_EN   => e2_ch4_rx_val,     -- in  std_logic;                      -- RX Input Data Clock Enable
    E2_RX_DATA     => e2_ch4_rx_data,    -- in  std_logic;                      -- RX Input Data
    E2_RX_LCV      => gnd,               -- in  std_logic;                      -- RX Code Violation
    E2_RX_LOS      => E3_RX_LOS,         -- in  std_logic;                      -- RX Loss Of Signal
    E2_RX_LOL      => E3_RX_LOL,         -- in  std_logic;                      -- RX Loss Of Lock
    E2_REF_CLK     => open,              -- out std_logic;                      -- Output Ref. Clock
    E2_REF_CLK_EN  => open,              -- out std_logic;                      -- Output Ref. Clock Enable
    E2_FRAME_START => open,              -- out std_logic;                      -- Frame Pulse
    E2_SYNC        => E2_CH4_SYNC,       -- out std_logic;                      -- State : Frame Synchronous
    E2_RAI         => E2_CH4_RAI,        -- out std_logic;                      -- State : RAI Bit
    E2_NA          => E2_CH4_NA,         -- out std_logic;                      -- State : NA Bit
    E2_AIS         => E2_CH4_AIS,        -- out std_logic;                      -- State : Alarm Ind. Signal
    E2_LOS         => E2_CH4_LOS,        -- out std_logic;                      -- State : Loss Of Signal
    E1_CH1_RX_VAL  => E1_CH41_RX_VAL,    -- out std_logic;                      -- E1 Channel 1 Data Valid
    E1_CH1_RX_DATA => E1_CH41_RX_DATA,   -- out std_logic;                      -- E1 Channel 1 Data
    E1_CH2_RX_VAL  => E1_CH42_RX_VAL,    -- out std_logic;                      -- E1 Channel 2 Data Valid
    E1_CH2_RX_DATA => E1_CH42_RX_DATA,   -- out std_logic;                      -- E1 Channel 2 Data
    E1_CH3_RX_VAL  => E1_CH43_RX_VAL,    -- out std_logic;                      -- E1 Channel 3 Data Valid
    E1_CH3_RX_DATA => E1_CH43_RX_DATA,   -- out std_logic;                      -- E1 Channel 3 Data
    E1_CH4_RX_VAL  => E1_CH44_RX_VAL,    -- out std_logic;                      -- E1 Channel 4 Data Valid
    E1_CH4_RX_DATA => E1_CH44_RX_DATA,   -- out std_logic;                      -- E1 Channel 4 Data
    E2_REMOTE_EN   => gnd,               -- in  std_logic;                      -- Remote Channel : Enable
    E2_REMOTE_DATA => open               -- out std_logic_vector (3 downto 0)   -- Remote Channel : RX Data
  );

-- ********************************************************************************

end DEMULTIPLEXER_E3_TO_E1;

-- ********************************************************************************
-- List Of Changes
-- ===============
-- DATE        VERSION  NAME  CHANGE
-- 11.07.2004  1.0      ThG   Creation
-- ********************************************************************************
