-- ********************************************************************************
-- *  Copyright (C) Thorsten Gaertner, Oststeinbek / Germany 2004                 *
-- ********************************************************************************
--
-- ********************************************************************************
-- *  This source file is provided "as is" and WITHOUT any express or implied     *
-- *  warranties, that this source file is                                        *
-- *  1. free from any claims of infringement,                                    *
-- *  2. the merchantability or fitness for a particular purpose.                 *
-- ********************************************************************************
--
-- ********************************************************************************
-- *  File        : MULTIPLEXER_E1_TO_E3.vhd                                      *
-- *  Version     : 1.0                                                           *
-- *  Target      : Plain VHDL                                                    *
-- *  Description : E3 (G.751) Multiplexer for 16 E1 transparent (G.704) channels *
-- *                with E2 (G.742) intermediate layer                            *
-- ********************************************************************************

library IEEE;
use     IEEE.STD_LOGIC_1164.ALL;
use     IEEE.STD_LOGIC_ARITH.ALL;
use     IEEE.STD_LOGIC_UNSIGNED.ALL;

-- ********************************************************************************

entity MULTIPLEXER_E1_TO_E3 is
  port (
    E3_REF_CLK      : in  std_logic;                      -- Framer Clock E3
    RESET           : in  std_logic;                      -- Reset
    E2_CH1_RAI      : in  std_logic;                      -- E2 Channel 1 Remote Alarm Indication
    E2_CH1_NA       : in  std_logic;                      -- E2 Channel 1 National Bit
    E2_CH2_RAI      : in  std_logic;                      -- E2 Channel 2 Remote Alarm Indication
    E2_CH2_NA       : in  std_logic;                      -- E2 Channel 2 National Bit
    E2_CH3_RAI      : in  std_logic;                      -- E2 Channel 3 Remote Alarm Indication
    E2_CH3_NA       : in  std_logic;                      -- E2 Channel 3 National Bit
    E2_CH4_RAI      : in  std_logic;                      -- E2 Channel 4 Remote Alarm Indication
    E2_CH4_NA       : in  std_logic;                      -- E2 Channel 4 National Bit
    E3_RAI          : in  std_logic;                      -- E3 Remote Alarm Indication
    E3_NA           : in  std_logic;                      -- E3 National Bit
    E3_FRAME_START  : out std_logic;                      -- E3 Frame Pulse
    E3_IDLE_SET     : in  std_logic;                      -- E3 Pulse : new IDLE Command
    E3_IDLE_CMD     : in  std_logic_vector (2 downto 0);  -- E3 IDLE Command
    E3_FAS_SET      : in  std_logic;                      -- E3 Pulse : new FAS Command
    E3_FAS_CMD      : in  std_logic_vector (2 downto 0);  -- E3 FAS Command
    E3_REMOTE_EN    : in  std_logic;                      -- E3 Remote Channel : Enable
    E3_REMOTE_DATA  : in  std_logic_vector (3 downto 0);  -- E3 Remote Channel : TX Data
    E1_CH11_TX_CLK  : in  std_logic;                      -- E1 Channel 11 Clock
    E1_CH11_TX_VAL  : in  std_logic;                      -- E1 Channel 11 Data Valid
    E1_CH11_TX_DATA : in  std_logic;                      -- E1 Channel 11 Data
    E1_CH12_TX_CLK  : in  std_logic;                      -- E1 Channel 12 Clock
    E1_CH12_TX_VAL  : in  std_logic;                      -- E1 Channel 12 Data Valid
    E1_CH12_TX_DATA : in  std_logic;                      -- E1 Channel 12 Data
    E1_CH13_TX_CLK  : in  std_logic;                      -- E1 Channel 13 Clock
    E1_CH13_TX_VAL  : in  std_logic;                      -- E1 Channel 13 Data Valid
    E1_CH13_TX_DATA : in  std_logic;                      -- E1 Channel 13 Data
    E1_CH14_TX_CLK  : in  std_logic;                      -- E1 Channel 14 Clock
    E1_CH14_TX_VAL  : in  std_logic;                      -- E1 Channel 14 Data Valid
    E1_CH14_TX_DATA : in  std_logic;                      -- E1 Channel 14 Data
    E1_CH21_TX_CLK  : in  std_logic;                      -- E1 Channel 21 Clock
    E1_CH21_TX_VAL  : in  std_logic;                      -- E1 Channel 21 Data Valid
    E1_CH21_TX_DATA : in  std_logic;                      -- E1 Channel 21 Data
    E1_CH22_TX_CLK  : in  std_logic;                      -- E1 Channel 22 Clock
    E1_CH22_TX_VAL  : in  std_logic;                      -- E1 Channel 22 Data Valid
    E1_CH22_TX_DATA : in  std_logic;                      -- E1 Channel 22 Data
    E1_CH23_TX_CLK  : in  std_logic;                      -- E1 Channel 23 Clock
    E1_CH23_TX_VAL  : in  std_logic;                      -- E1 Channel 23 Data Valid
    E1_CH23_TX_DATA : in  std_logic;                      -- E1 Channel 23 Data
    E1_CH24_TX_CLK  : in  std_logic;                      -- E1 Channel 24 Clock
    E1_CH24_TX_VAL  : in  std_logic;                      -- E1 Channel 24 Data Valid
    E1_CH24_TX_DATA : in  std_logic;                      -- E1 Channel 24 Data
    E1_CH31_TX_CLK  : in  std_logic;                      -- E1 Channel 31 Clock
    E1_CH31_TX_VAL  : in  std_logic;                      -- E1 Channel 31 Data Valid
    E1_CH31_TX_DATA : in  std_logic;                      -- E1 Channel 31 Data
    E1_CH32_TX_CLK  : in  std_logic;                      -- E1 Channel 32 Clock
    E1_CH32_TX_VAL  : in  std_logic;                      -- E1 Channel 32 Data Valid
    E1_CH32_TX_DATA : in  std_logic;                      -- E1 Channel 32 Data
    E1_CH33_TX_CLK  : in  std_logic;                      -- E1 Channel 33 Clock
    E1_CH33_TX_VAL  : in  std_logic;                      -- E1 Channel 33 Data Valid
    E1_CH33_TX_DATA : in  std_logic;                      -- E1 Channel 33 Data
    E1_CH34_TX_CLK  : in  std_logic;                      -- E1 Channel 34 Clock
    E1_CH34_TX_VAL  : in  std_logic;                      -- E1 Channel 34 Data Valid
    E1_CH34_TX_DATA : in  std_logic;                      -- E1 Channel 34 Data
    E1_CH41_TX_CLK  : in  std_logic;                      -- E1 Channel 41 Clock
    E1_CH41_TX_VAL  : in  std_logic;                      -- E1 Channel 41 Data Valid
    E1_CH41_TX_DATA : in  std_logic;                      -- E1 Channel 41 Data
    E1_CH42_TX_CLK  : in  std_logic;                      -- E1 Channel 42 Clock
    E1_CH42_TX_VAL  : in  std_logic;                      -- E1 Channel 42 Data Valid
    E1_CH42_TX_DATA : in  std_logic;                      -- E1 Channel 42 Data
    E1_CH43_TX_CLK  : in  std_logic;                      -- E1 Channel 43 Clock
    E1_CH43_TX_VAL  : in  std_logic;                      -- E1 Channel 43 Data Valid
    E1_CH43_TX_DATA : in  std_logic;                      -- E1 Channel 43 Data
    E1_CH44_TX_CLK  : in  std_logic;                      -- E1 Channel 44 Clock
    E1_CH44_TX_VAL  : in  std_logic;                      -- E1 Channel 44 Data Valid
    E1_CH44_TX_DATA : in  std_logic;                      -- E1 Channel 44 Data
    E2_TX_ERR       : out std_logic;                      -- E2 Fifo Error
    E1_TX_ERR       : out std_logic;                      -- E1 Fifo Error
    E3_TX_CLK       : out std_logic;                      -- E3 Output Clock
    E3_TX_DATA      : out std_logic                       -- E3 Output Data
  );
end MULTIPLEXER_E1_TO_E3;

-- ********************************************************************************

architecture MULTIPLEXER_E1_TO_E3 of MULTIPLEXER_E1_TO_E3 is

-- ********************************************************************************

component E2_CLK_GEN_FROM_E3
  port (
    E3_REF_CLK     : in  std_logic;  -- Framer Clock E3
    RESET          : in  std_logic;  -- Reset
    E2_REF_CLK     : out std_logic;  -- Framer Clock E2
    E2_REF_CLK_EN  : out std_logic   -- Framer Clock E2 Enable
  );
end component;

-- ********************************************************************************

component E2_G742_FRAMER
  port (
    E2_REF_CLK     : in  std_logic;                      -- Framer Clock
    E2_REF_CLK_EN  : in  std_logic;                      -- Framer Clock Enable
    RESET          : in  std_logic;                      -- Reset
    E1_CH1_TX_CLK  : in  std_logic;                      -- E1 Channel 1 Clock
    E1_CH1_TX_VAL  : in  std_logic;                      -- E1 Channel 1 Data Valid
    E1_CH1_TX_DATA : in  std_logic;                      -- E1 Channel 1 Data
    E1_CH1_TX_ERR  : out std_logic;                      -- E1 Channel 1 Error-Out
    E1_CH2_TX_CLK  : in  std_logic;                      -- E1 Channel 2 Clock
    E1_CH2_TX_VAL  : in  std_logic;                      -- E1 Channel 2 Data Valid
    E1_CH2_TX_DATA : in  std_logic;                      -- E1 Channel 2 Data
    E1_CH2_TX_ERR  : out std_logic;                      -- E1 Channel 2 Error-Out
    E1_CH3_TX_CLK  : in  std_logic;                      -- E1 Channel 3 Clock
    E1_CH3_TX_VAL  : in  std_logic;                      -- E1 Channel 3 Data Valid
    E1_CH3_TX_DATA : in  std_logic;                      -- E1 Channel 3 Data
    E1_CH3_TX_ERR  : out std_logic;                      -- E1 Channel 3 Error-Out
    E1_CH4_TX_CLK  : in  std_logic;                      -- E1 Channel 4 Clock
    E1_CH4_TX_VAL  : in  std_logic;                      -- E1 Channel 4 Data Valid
    E1_CH4_TX_DATA : in  std_logic;                      -- E1 Channel 4 Data
    E1_CH4_TX_ERR  : out std_logic;                      -- E1 Channel 4 Error-Out
    E2_RAI         : in  std_logic;                      -- Remote Alarm Indication
    E2_NA          : in  std_logic;                      -- National Bit
    E2_FRAME_START : out std_logic;                      -- Frame Pulse
    E2_IDLE_SET    : in  std_logic;                      -- Pulse : new IDLE Command
    E2_IDLE_CMD    : in  std_logic_vector (2 downto 0);  -- IDLE Command
    E2_FAS_SET     : in  std_logic;                      -- Pulse : new FAS Command
    E2_FAS_CMD     : in  std_logic_vector (2 downto 0);  -- FAS Command
    E2_REMOTE_EN   : in  std_logic;                      -- Remote Channel : Enable
    E2_REMOTE_DATA : in  std_logic_vector (3 downto 0);  -- Remote Channel : TX Data
    E2_TX_CLK      : out std_logic;                      -- E2 Output Clock
    E2_TX_CLK_EN   : out std_logic;                      -- E2 Output Clock Enable
    E2_TX_DATA     : out std_logic                       -- E2 Output Data
  );
end component;

-- ********************************************************************************

component E3_G751_FRAMER
  port (
    E3_REF_CLK     : in  std_logic;                      -- Framer Clock
    RESET          : in  std_logic;                      -- Reset
    E2_CH1_TX_CLK  : in  std_logic;                      -- E2 Channel 1 Clock
    E2_CH1_TX_VAL  : in  std_logic;                      -- E2 Channel 1 Data Valid
    E2_CH1_TX_DATA : in  std_logic;                      -- E2 Channel 1 Data
    E2_CH1_TX_ERR  : out std_logic;                      -- E2 Channel 1 Error-Out
    E2_CH2_TX_CLK  : in  std_logic;                      -- E2 Channel 2 Clock
    E2_CH2_TX_VAL  : in  std_logic;                      -- E2 Channel 2 Data Valid
    E2_CH2_TX_DATA : in  std_logic;                      -- E2 Channel 2 Data
    E2_CH2_TX_ERR  : out std_logic;                      -- E2 Channel 2 Error-Out
    E2_CH3_TX_CLK  : in  std_logic;                      -- E2 Channel 3 Clock
    E2_CH3_TX_VAL  : in  std_logic;                      -- E2 Channel 3 Data Valid
    E2_CH3_TX_DATA : in  std_logic;                      -- E2 Channel 3 Data
    E2_CH3_TX_ERR  : out std_logic;                      -- E2 Channel 3 Error-Out
    E2_CH4_TX_CLK  : in  std_logic;                      -- E2 Channel 4 Clock
    E2_CH4_TX_VAL  : in  std_logic;                      -- E2 Channel 4 Data Valid
    E2_CH4_TX_DATA : in  std_logic;                      -- E2 Channel 4 Data
    E2_CH4_TX_ERR  : out std_logic;                      -- E2 Channel 4 Error-Out
    E3_RAI         : in  std_logic;                      -- Remote Alarm Indication
    E3_NA          : in  std_logic;                      -- National Bit
    E3_FRAME_START : out std_logic;                      -- Frame Pulse
    E3_IDLE_SET    : in  std_logic;                      -- Pulse : new IDLE Command
    E3_IDLE_CMD    : in  std_logic_vector (2 downto 0);  -- IDLE Command
    E3_FAS_SET     : in  std_logic;                      -- Pulse : new FAS Command
    E3_FAS_CMD     : in  std_logic_vector (2 downto 0);  -- FAS Command
    E3_REMOTE_EN   : in  std_logic;                      -- Remote Channel : Enable
    E3_REMOTE_DATA : in  std_logic_vector (3 downto 0);  -- Remote Channel : TX Data
    E3_TX_CLK      : out std_logic;                      -- E3 Output Clock
    E3_TX_DATA     : out std_logic                       -- E3 Output Data
  );
end component;

-- ********************************************************************************

signal e2_ref_clk      , e2_ref_clk_en                                        : std_logic;
signal e1_ch11_tx_err  , e1_ch21_tx_err  , e1_ch31_tx_err  , e1_ch41_tx_err   : std_logic;
signal e1_ch12_tx_err  , e1_ch22_tx_err  , e1_ch32_tx_err  , e1_ch42_tx_err   : std_logic;
signal e1_ch13_tx_err  , e1_ch23_tx_err  , e1_ch33_tx_err  , e1_ch43_tx_err   : std_logic;
signal e1_ch14_tx_err  , e1_ch24_tx_err  , e1_ch34_tx_err  , e1_ch44_tx_err   : std_logic;
signal e2_ch1_tx_err   , e2_ch2_tx_err   , e2_ch3_tx_err   , e2_ch4_tx_err    : std_logic;
signal e2_ch1_tx_clk   , e2_ch2_tx_clk   , e2_ch3_tx_clk   , e2_ch4_tx_clk    : std_logic;
signal e2_ch1_tx_clk_en, e2_ch2_tx_clk_en, e2_ch3_tx_clk_en, e2_ch4_tx_clk_en : std_logic;
signal e2_ch1_tx_data  , e2_ch2_tx_data  , e2_ch3_tx_data  , e2_ch4_tx_data   : std_logic;
signal gnd                                                                    : std_logic;
signal gnd_3                                                                  : std_logic_vector (2 downto 0);
signal gnd_4                                                                  : std_logic_vector (3 downto 0);

-- ********************************************************************************

begin

-- ********************************************************************************

gnd   <= '0';
gnd_3 <= "000";
gnd_4 <= "0000";

-- ********************************************************************************
-- * Generation of E2 clock 8448 kHz from E3 clock 34368 kHz                      *
-- ********************************************************************************

E2_CLK : E2_CLK_GEN_FROM_E3
  port map (
    E3_REF_CLK     => E3_REF_CLK,     -- in  std_logic;  -- Framer Clock E3
    RESET          => RESET,          -- in  std_logic;  -- Reset
    E2_REF_CLK     => e2_ref_clk,     -- out std_logic;  -- Framer Clock E2
    E2_REF_CLK_EN  => e2_ref_clk_en   -- out std_logic   -- Framer Clock E2 Enable
  );

-- ********************************************************************************
-- * E2-Framer (TX) according to ITU-T G.742 (8448 kbit/sec) :  FRAMER No. 1      *
-- ********************************************************************************

E2_FRAMER_1 : E2_G742_FRAMER
  port map (
    E2_REF_CLK     => e2_ref_clk,        -- in  std_logic;                      -- Framer Clock
    E2_REF_CLK_EN  => e2_ref_clk_en,     -- in  std_logic;                      -- Framer Clock Enable
    RESET          => RESET,             -- in  std_logic;                      -- Reset
    E1_CH1_TX_CLK  => E1_CH11_TX_CLK,    -- in  std_logic;                      -- E1 Channel 1 Clock
    E1_CH1_TX_VAL  => E1_CH11_TX_VAL,    -- in  std_logic;                      -- E1 Channel 1 Data Valid
    E1_CH1_TX_DATA => E1_CH11_TX_DATA,   -- in  std_logic;                      -- E1 Channel 1 Data
    E1_CH1_TX_ERR  => e1_ch11_tx_err,    -- out std_logic;                      -- E1 Channel 1 Error-Out
    E1_CH2_TX_CLK  => E1_CH12_TX_CLK,    -- in  std_logic;                      -- E1 Channel 2 Clock
    E1_CH2_TX_VAL  => E1_CH12_TX_VAL,    -- in  std_logic;                      -- E1 Channel 2 Data Valid
    E1_CH2_TX_DATA => E1_CH12_TX_DATA,   -- in  std_logic;                      -- E1 Channel 2 Data
    E1_CH2_TX_ERR  => e1_ch12_tx_err,    -- out std_logic;                      -- E1 Channel 2 Error-Out
    E1_CH3_TX_CLK  => E1_CH13_TX_CLK,    -- in  std_logic;                      -- E1 Channel 3 Clock
    E1_CH3_TX_VAL  => E1_CH13_TX_VAL,    -- in  std_logic;                      -- E1 Channel 3 Data Valid
    E1_CH3_TX_DATA => E1_CH13_TX_DATA,   -- in  std_logic;                      -- E1 Channel 3 Data
    E1_CH3_TX_ERR  => e1_ch13_tx_err,    -- out std_logic;                      -- E1 Channel 3 Error-Out
    E1_CH4_TX_CLK  => E1_CH14_TX_CLK,    -- in  std_logic;                      -- E1 Channel 4 Clock
    E1_CH4_TX_VAL  => E1_CH14_TX_VAL,    -- in  std_logic;                      -- E1 Channel 4 Data Valid
    E1_CH4_TX_DATA => E1_CH14_TX_DATA,   -- in  std_logic;                      -- E1 Channel 4 Data
    E1_CH4_TX_ERR  => e1_ch14_tx_err,    -- out std_logic;                      -- E1 Channel 4 Error-Out
    E2_RAI         => E2_CH1_RAI,        -- in  std_logic;                      -- Remote Alarm Indication
    E2_NA          => E2_CH1_NA,         -- in  std_logic;                      -- National Bit
    E2_FRAME_START => open,              -- out std_logic;                      -- Frame Pulse
    E2_IDLE_SET    => gnd,               -- in  std_logic;                      -- Pulse : new IDLE Command
    E2_IDLE_CMD    => gnd_3,             -- in  std_logic_vector (2 downto 0);  -- IDLE Command
    E2_FAS_SET     => gnd,               -- in  std_logic;                      -- Pulse : new FAS Command
    E2_FAS_CMD     => gnd_3,             -- in  std_logic_vector (2 downto 0);  -- FAS Command
    E2_REMOTE_EN   => gnd,               -- in  std_logic;                      -- Remote Channel : Enable
    E2_REMOTE_DATA => gnd_4,             -- in  std_logic_vector (3 downto 0);  -- Remote Channel : TX Data
    E2_TX_CLK      => e2_ch1_tx_clk,     -- out std_logic;                      -- E2 Output Clock
    E2_TX_CLK_EN   => e2_ch1_tx_clk_en,  -- out std_logic;                      -- E2 Output Clock Enable
    E2_TX_DATA     => e2_ch1_tx_data     -- out std_logic                       -- E2 Output Data
  );

-- ********************************************************************************
-- * E2-Framer (TX) according to ITU-T G.742 (8448 kbit/sec) :  FRAMER No. 2      *
-- ********************************************************************************

E2_FRAMER_2 : E2_G742_FRAMER
  port map (
    E2_REF_CLK     => e2_ref_clk,        -- in  std_logic;                      -- Framer Clock
    E2_REF_CLK_EN  => e2_ref_clk_en,     -- in  std_logic;                      -- Framer Clock Enable
    RESET          => RESET,             -- in  std_logic;                      -- Reset
    E1_CH1_TX_CLK  => E1_CH21_TX_CLK,    -- in  std_logic;                      -- E1 Channel 1 Clock
    E1_CH1_TX_VAL  => E1_CH21_TX_VAL,    -- in  std_logic;                      -- E1 Channel 1 Data Valid
    E1_CH1_TX_DATA => E1_CH21_TX_DATA,   -- in  std_logic;                      -- E1 Channel 1 Data
    E1_CH1_TX_ERR  => e1_ch21_tx_err,    -- out std_logic;                      -- E1 Channel 1 Error-Out
    E1_CH2_TX_CLK  => E1_CH22_TX_CLK,    -- in  std_logic;                      -- E1 Channel 2 Clock
    E1_CH2_TX_VAL  => E1_CH22_TX_VAL,    -- in  std_logic;                      -- E1 Channel 2 Data Valid
    E1_CH2_TX_DATA => E1_CH22_TX_DATA,   -- in  std_logic;                      -- E1 Channel 2 Data
    E1_CH2_TX_ERR  => e1_ch22_tx_err,    -- out std_logic;                      -- E1 Channel 2 Error-Out
    E1_CH3_TX_CLK  => E1_CH23_TX_CLK,    -- in  std_logic;                      -- E1 Channel 3 Clock
    E1_CH3_TX_VAL  => E1_CH23_TX_VAL,    -- in  std_logic;                      -- E1 Channel 3 Data Valid
    E1_CH3_TX_DATA => E1_CH23_TX_DATA,   -- in  std_logic;                      -- E1 Channel 3 Data
    E1_CH3_TX_ERR  => e1_ch23_tx_err,    -- out std_logic;                      -- E1 Channel 3 Error-Out
    E1_CH4_TX_CLK  => E1_CH24_TX_CLK,    -- in  std_logic;                      -- E1 Channel 4 Clock
    E1_CH4_TX_VAL  => E1_CH24_TX_VAL,    -- in  std_logic;                      -- E1 Channel 4 Data Valid
    E1_CH4_TX_DATA => E1_CH24_TX_DATA,   -- in  std_logic;                      -- E1 Channel 4 Data
    E1_CH4_TX_ERR  => e1_ch24_tx_err,    -- out std_logic;                      -- E1 Channel 4 Error-Out
    E2_RAI         => E2_CH2_RAI,        -- in  std_logic;                      -- Remote Alarm Indication
    E2_NA          => E2_CH2_NA,         -- in  std_logic;                      -- National Bit
    E2_FRAME_START => open,              -- out std_logic;                      -- Frame Pulse
    E2_IDLE_SET    => gnd,               -- in  std_logic;                      -- Pulse : new IDLE Command
    E2_IDLE_CMD    => gnd_3,             -- in  std_logic_vector (2 downto 0);  -- IDLE Command
    E2_FAS_SET     => gnd,               -- in  std_logic;                      -- Pulse : new FAS Command
    E2_FAS_CMD     => gnd_3,             -- in  std_logic_vector (2 downto 0);  -- FAS Command
    E2_REMOTE_EN   => gnd,               -- in  std_logic;                      -- Remote Channel : Enable
    E2_REMOTE_DATA => gnd_4,             -- in  std_logic_vector (3 downto 0);  -- Remote Channel : TX Data
    E2_TX_CLK      => e2_ch2_tx_clk,     -- out std_logic;                      -- E2 Output Clock
    E2_TX_CLK_EN   => e2_ch2_tx_clk_en,  -- out std_logic;                      -- E2 Output Clock Enable
    E2_TX_DATA     => e2_ch2_tx_data     -- out std_logic                       -- E2 Output Data
  );

-- ********************************************************************************
-- * E2-Framer (TX) according to ITU-T G.742 (8448 kbit/sec) :  FRAMER No. 3      *
-- ********************************************************************************

E2_FRAMER_3 : E2_G742_FRAMER
  port map (
    E2_REF_CLK     => e2_ref_clk,        -- in  std_logic;                      -- Framer Clock
    E2_REF_CLK_EN  => e2_ref_clk_en,     -- in  std_logic;                      -- Framer Clock Enable
    RESET          => RESET,             -- in  std_logic;                      -- Reset
    E1_CH1_TX_CLK  => E1_CH31_TX_CLK,    -- in  std_logic;                      -- E1 Channel 1 Clock
    E1_CH1_TX_VAL  => E1_CH31_TX_VAL,    -- in  std_logic;                      -- E1 Channel 1 Data Valid
    E1_CH1_TX_DATA => E1_CH31_TX_DATA,   -- in  std_logic;                      -- E1 Channel 1 Data
    E1_CH1_TX_ERR  => e1_ch31_tx_err,    -- out std_logic;                      -- E1 Channel 1 Error-Out
    E1_CH2_TX_CLK  => E1_CH32_TX_CLK,    -- in  std_logic;                      -- E1 Channel 2 Clock
    E1_CH2_TX_VAL  => E1_CH32_TX_VAL,    -- in  std_logic;                      -- E1 Channel 2 Data Valid
    E1_CH2_TX_DATA => E1_CH32_TX_DATA,   -- in  std_logic;                      -- E1 Channel 2 Data
    E1_CH2_TX_ERR  => e1_ch32_tx_err,    -- out std_logic;                      -- E1 Channel 2 Error-Out
    E1_CH3_TX_CLK  => E1_CH33_TX_CLK,    -- in  std_logic;                      -- E1 Channel 3 Clock
    E1_CH3_TX_VAL  => E1_CH33_TX_VAL,    -- in  std_logic;                      -- E1 Channel 3 Data Valid
    E1_CH3_TX_DATA => E1_CH33_TX_DATA,   -- in  std_logic;                      -- E1 Channel 3 Data
    E1_CH3_TX_ERR  => e1_ch33_tx_err,    -- out std_logic;                      -- E1 Channel 3 Error-Out
    E1_CH4_TX_CLK  => E1_CH34_TX_CLK,    -- in  std_logic;                      -- E1 Channel 4 Clock
    E1_CH4_TX_VAL  => E1_CH34_TX_VAL,    -- in  std_logic;                      -- E1 Channel 4 Data Valid
    E1_CH4_TX_DATA => E1_CH34_TX_DATA,   -- in  std_logic;                      -- E1 Channel 4 Data
    E1_CH4_TX_ERR  => e1_ch34_tx_err,    -- out std_logic;                      -- E1 Channel 4 Error-Out
    E2_RAI         => E2_CH3_RAI,        -- in  std_logic;                      -- Remote Alarm Indication
    E2_NA          => E2_CH3_NA,         -- in  std_logic;                      -- National Bit
    E2_FRAME_START => open,              -- out std_logic;                      -- Frame Pulse
    E2_IDLE_SET    => gnd,               -- in  std_logic;                      -- Pulse : new IDLE Command
    E2_IDLE_CMD    => gnd_3,             -- in  std_logic_vector (2 downto 0);  -- IDLE Command
    E2_FAS_SET     => gnd,               -- in  std_logic;                      -- Pulse : new FAS Command
    E2_FAS_CMD     => gnd_3,             -- in  std_logic_vector (2 downto 0);  -- FAS Command
    E2_REMOTE_EN   => gnd,               -- in  std_logic;                      -- Remote Channel : Enable
    E2_REMOTE_DATA => gnd_4,             -- in  std_logic_vector (3 downto 0);  -- Remote Channel : TX Data
    E2_TX_CLK      => e2_ch3_tx_clk,     -- out std_logic;                      -- E2 Output Clock
    E2_TX_CLK_EN   => e2_ch3_tx_clk_en,  -- out std_logic;                      -- E2 Output Clock Enable
    E2_TX_DATA     => e2_ch3_tx_data     -- out std_logic                       -- E2 Output Data
  );

-- ********************************************************************************
-- * E2-Framer (TX) according to ITU-T G.742 (8448 kbit/sec) :  FRAMER No. 4      *
-- ********************************************************************************

E2_FRAMER_4 : E2_G742_FRAMER
  port map (
    E2_REF_CLK     => e2_ref_clk,        -- in  std_logic;                      -- Framer Clock
    E2_REF_CLK_EN  => e2_ref_clk_en,     -- in  std_logic;                      -- Framer Clock Enable
    RESET          => RESET,             -- in  std_logic;                      -- Reset
    E1_CH1_TX_CLK  => E1_CH41_TX_CLK,    -- in  std_logic;                      -- E1 Channel 1 Clock
    E1_CH1_TX_VAL  => E1_CH41_TX_VAL,    -- in  std_logic;                      -- E1 Channel 1 Data Valid
    E1_CH1_TX_DATA => E1_CH41_TX_DATA,   -- in  std_logic;                      -- E1 Channel 1 Data
    E1_CH1_TX_ERR  => e1_ch41_tx_err,    -- out std_logic;                      -- E1 Channel 1 Error-Out
    E1_CH2_TX_CLK  => E1_CH42_TX_CLK,    -- in  std_logic;                      -- E1 Channel 2 Clock
    E1_CH2_TX_VAL  => E1_CH42_TX_VAL,    -- in  std_logic;                      -- E1 Channel 2 Data Valid
    E1_CH2_TX_DATA => E1_CH42_TX_DATA,   -- in  std_logic;                      -- E1 Channel 2 Data
    E1_CH2_TX_ERR  => e1_ch42_tx_err,    -- out std_logic;                      -- E1 Channel 2 Error-Out
    E1_CH3_TX_CLK  => E1_CH43_TX_CLK,    -- in  std_logic;                      -- E1 Channel 3 Clock
    E1_CH3_TX_VAL  => E1_CH43_TX_VAL,    -- in  std_logic;                      -- E1 Channel 3 Data Valid
    E1_CH3_TX_DATA => E1_CH43_TX_DATA,   -- in  std_logic;                      -- E1 Channel 3 Data
    E1_CH3_TX_ERR  => e1_ch43_tx_err,    -- out std_logic;                      -- E1 Channel 3 Error-Out
    E1_CH4_TX_CLK  => E1_CH44_TX_CLK,    -- in  std_logic;                      -- E1 Channel 4 Clock
    E1_CH4_TX_VAL  => E1_CH44_TX_VAL,    -- in  std_logic;                      -- E1 Channel 4 Data Valid
    E1_CH4_TX_DATA => E1_CH44_TX_DATA,   -- in  std_logic;                      -- E1 Channel 4 Data
    E1_CH4_TX_ERR  => e1_ch44_tx_err,    -- out std_logic;                      -- E1 Channel 4 Error-Out
    E2_RAI         => E2_CH4_RAI,        -- in  std_logic;                      -- Remote Alarm Indication
    E2_NA          => E2_CH4_NA,         -- in  std_logic;                      -- National Bit
    E2_FRAME_START => open,              -- out std_logic;                      -- Frame Pulse
    E2_IDLE_SET    => gnd,               -- in  std_logic;                      -- Pulse : new IDLE Command
    E2_IDLE_CMD    => gnd_3,             -- in  std_logic_vector (2 downto 0);  -- IDLE Command
    E2_FAS_SET     => gnd,               -- in  std_logic;                      -- Pulse : new FAS Command
    E2_FAS_CMD     => gnd_3,             -- in  std_logic_vector (2 downto 0);  -- FAS Command
    E2_REMOTE_EN   => gnd,               -- in  std_logic;                      -- Remote Channel : Enable
    E2_REMOTE_DATA => gnd_4,             -- in  std_logic_vector (3 downto 0);  -- Remote Channel : TX Data
    E2_TX_CLK      => e2_ch4_tx_clk,     -- out std_logic;                      -- E2 Output Clock
    E2_TX_CLK_EN   => e2_ch4_tx_clk_en,  -- out std_logic;                      -- E2 Output Clock Enable
    E2_TX_DATA     => e2_ch4_tx_data     -- out std_logic                       -- E2 Output Data
  );

-- ********************************************************************************
-- * E3-Framer (TX) according to ITU-T G.751 (34368 kbit/sec) : LINE - FRAMER     *
-- ********************************************************************************

E3_FRAMER : E3_G751_FRAMER
  port map (
    E3_REF_CLK     => E3_REF_CLK,        -- in  std_logic;                      -- Framer Clock
    RESET          => RESET,             -- in  std_logic;                      -- Reset
    E2_CH1_TX_CLK  => e2_ch1_tx_clk,     -- in  std_logic;                      -- E2 Channel 1 Clock
    E2_CH1_TX_VAL  => e2_ch1_tx_clk_en,  -- in  std_logic;                      -- E2 Channel 1 Data Valid
    E2_CH1_TX_DATA => e2_ch1_tx_data,    -- in  std_logic;                      -- E2 Channel 1 Data
    E2_CH1_TX_ERR  => e2_ch1_tx_err,     -- out std_logic;                      -- E2 Channel 1 Error-Out
    E2_CH2_TX_CLK  => e2_ch2_tx_clk,     -- in  std_logic;                      -- E2 Channel 2 Clock
    E2_CH2_TX_VAL  => e2_ch2_tx_clk_en,  -- in  std_logic;                      -- E2 Channel 2 Data Valid
    E2_CH2_TX_DATA => e2_ch2_tx_data,    -- in  std_logic;                      -- E2 Channel 2 Data
    E2_CH2_TX_ERR  => e2_ch2_tx_err,     -- out std_logic;                      -- E2 Channel 2 Error-Out
    E2_CH3_TX_CLK  => e2_ch3_tx_clk,     -- in  std_logic;                      -- E2 Channel 3 Clock
    E2_CH3_TX_VAL  => e2_ch3_tx_clk_en,  -- in  std_logic;                      -- E2 Channel 3 Data Valid
    E2_CH3_TX_DATA => e2_ch3_tx_data,    -- in  std_logic;                      -- E2 Channel 3 Data
    E2_CH3_TX_ERR  => e2_ch3_tx_err,     -- out std_logic;                      -- E2 Channel 3 Error-Out
    E2_CH4_TX_CLK  => e2_ch4_tx_clk,     -- in  std_logic;                      -- E2 Channel 4 Clock
    E2_CH4_TX_VAL  => e2_ch4_tx_clk_en,  -- in  std_logic;                      -- E2 Channel 4 Data Valid
    E2_CH4_TX_DATA => e2_ch4_tx_data,    -- in  std_logic;                      -- E2 Channel 4 Data
    E2_CH4_TX_ERR  => e2_ch4_tx_err,     -- out std_logic;                      -- E2 Channel 4 Error-Out
    E3_RAI         => E3_RAI,            -- in  std_logic;                      -- Remote Alarm Indication
    E3_NA          => E3_NA,             -- in  std_logic;                      -- National Bit
    E3_FRAME_START => E3_FRAME_START,    -- out std_logic;                      -- Frame Pulse
    E3_IDLE_SET    => E3_IDLE_SET,       -- in  std_logic;                      -- Pulse : new IDLE Command
    E3_IDLE_CMD    => E3_IDLE_CMD,       -- in  std_logic_vector (2 downto 0);  -- IDLE Command
    E3_FAS_SET     => E3_FAS_SET,        -- in  std_logic;                      -- Pulse : new FAS Command
    E3_FAS_CMD     => E3_FAS_CMD,        -- in  std_logic_vector (2 downto 0);  -- FAS Command
    E3_REMOTE_EN   => E3_REMOTE_EN,      -- in  std_logic;                      -- Remote Channel : Enable
    E3_REMOTE_DATA => E3_REMOTE_DATA,    -- in  std_logic_vector (3 downto 0);  -- Remote Channel : TX Data
    E3_TX_CLK      => E3_TX_CLK,         -- out std_logic;                      -- E3 Output Clock
    E3_TX_DATA     => E3_TX_DATA         -- out std_logic                       -- E3 Output Data
  );

-- ********************************************************************************
-- * Monitoring signals for fifo errors (full or empty) : for E2 and E1 layer     *
-- ********************************************************************************

FIFO_ERR : process (E3_REF_CLK, RESET)
begin
  if (RESET = '1') then

    E2_TX_ERR <= '0';
    E1_TX_ERR <= '0';

  elsif rising_edge (E3_REF_CLK) then

    E2_TX_ERR <= e2_ch1_tx_err  or e2_ch2_tx_err  or e2_ch3_tx_err  or e2_ch4_tx_err;

    E1_TX_ERR <= e1_ch11_tx_err or e1_ch12_tx_err or e1_ch13_tx_err or e1_ch14_tx_err or
                 e1_ch21_tx_err or e1_ch22_tx_err or e1_ch23_tx_err or e1_ch24_tx_err or
                 e1_ch31_tx_err or e1_ch32_tx_err or e1_ch33_tx_err or e1_ch34_tx_err or
                 e1_ch41_tx_err or e1_ch42_tx_err or e1_ch43_tx_err or e1_ch44_tx_err;

  end if;
end process;

-- ********************************************************************************

end MULTIPLEXER_E1_TO_E3;

-- ********************************************************************************
-- List Of Changes
-- ===============
-- DATE        VERSION  NAME  CHANGE
-- 10.07.2004  1.0      ThG   Creation
-- ********************************************************************************
